@@ -7,16 +7,20 @@ class Migration(DataMigration):
     def forwards(self, orm):
         from tendenci.apps.entities.models import Entity
         from tendenci.apps.user_groups.models import Group
-        groups = Group.objects.all()
-        if groups:
-            first_entity = Entity.objects.first()
-            for ugroup in groups:
-                if not ugroup.entity:
-                    ugroup.entity = first_entity
-                    ugroup.save()
-                if not ugroup.group:
-                    # the save method will take care of the auth group.
-                    ugroup.save()
+        # trap db errors so migrations can continue
+        try:
+            groups = Group.objects.all()
+            if groups:
+                first_entity = Entity.objects.first()
+                for ugroup in groups:
+                    if not ugroup.entity:
+                        ugroup.entity = first_entity
+                        ugroup.save()
+                    if not ugroup.group:
+                        # the save method will take care of the auth group.
+                        ugroup.save()
+        except:
+            pass
 
     def backwards(self, orm):
         pass
